@@ -7,81 +7,94 @@ bilibili_api
 import asyncio
 import platform
 
-from . import (
-    album,
-    app,
-    article,
-    article_category,
-    ass,
-    audio,
-    bangumi,
-    black_room,
-    channel,
-    channel_series,
-    cheese,
-    client,
-    comment,
-    creative_center,
-    dynamic,
-    emoji,
-    favorite_list,
-    game,
-    homepage,
-    hot,
-    interactive_video,
-    live,
-    live_area,
-    login,
-    login_func,
-    manga,
-    note,
-    rank,
-    search,
-    session,
-    settings,
-    topic,
-    user,
-    video,
-    video_tag,
-    video_uploader,
-    video_zone,
-    vote,
+from .utils.sync import sync
+from .credential import Credential
+from .utils.picture import Picture
+from .utils.short import get_real_url
+from .utils.parse_link import ResourceType, parse_link
+from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
+from .utils.danmaku import DmMode, Danmaku, DmFontSize, SpecialDanmaku
+from .utils.network_httpx import (
+    HEADERS,
+    Api,
+    retry,
+    enc_wbi,
+    get_nav,
+    request,
+    check_valid,
+    get_session,
+    set_session,
+    get_mixin_key,
 )
 from .errors import (
+    LoginError,
     ApiException,
     ArgsException,
-    CredentialNoBiliJctException,
-    CredentialNoBuvid3Exception,
-    CredentialNoDedeUserIDException,
-    CredentialNoSessdataException,
-    DanmakuClosedException,
-    DynamicExceedImagesException,
     LiveException,
-    LoginError,
     NetworkException,
-    ResponseCodeException,
     ResponseException,
     VideoUploadException,
+    ResponseCodeException,
+    DanmakuClosedException,
+    CredentialNoBuvid3Exception,
+    CredentialNoBiliJctException,
+    DynamicExceedImagesException,
+    CredentialNoSessdataException,
+    CredentialNoDedeUserIDException,
+)
+from . import (
+    app,
+    ass,
+    hot,
+    game,
+    live,
+    note,
+    rank,
+    user,
+    vote,
+    album,
+    audio,
+    emoji,
+    login,
+    manga,
+    topic,
+    video,
+    cheese,
+    client,
+    search,
+    article,
+    bangumi,
+    channel,
+    comment,
+    dynamic,
+    session,
+    homepage,
+    settings,
+    live_area,
+    video_tag,
+    black_room,
+    login_func,
+    video_zone,
+    favorite_list,
+    channel_series,
+    video_uploader,
+    creative_center,
+    article_category,
+    interactive_video,
 )
-from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
-from .utils.Credential import Credential
-from .utils.Danmaku import Danmaku, DmFontSize, DmMode, SpecialDanmaku
-from .utils.network_httpx import HEADERS, get_session, set_session, retry
-from .utils.parse_link import ResourceType, parse_link
-from .utils.Picture import Picture
-from .utils.short import get_real_url
-from .utils.sync import sync
 
-BILIBILI_API_VERSION = "15.4.4"
+BILIBILI_API_VERSION = "15.5.2"
 
 # 如果系统为 Windows，则修改默认策略，以解决代理报错问题
 if "windows" in platform.system().lower():
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())  # type: ignore
 
 __all__ = [
+    "Api",
     "ApiException",
     "ArgsException",
     "BILIBILI_API_VERSION",
+    "check_valid",
     "Credential",
     "CredentialNoBiliJctException",
     "CredentialNoBuvid3Exception",
@@ -92,6 +105,7 @@ __all__ = [
     "DmFontSize",
     "DmMode",
     "DynamicExceedImagesException",
+    "enc_wbi",
     "HEADERS",
     "LiveException",
     "LoginError",
@@ -123,6 +137,8 @@ __all__ = [
     "emoji",
     "favorite_list",
     "game",
+    "get_mixin_key",
+    "get_nav",
     "get_real_url",
     "get_session",
     "homepage",
@@ -137,6 +153,7 @@ __all__ = [
     "parse_link",
     "platform",
     "rank",
+    "request",
     "retry",
     "search",
     "session",
