@@ -4,26 +4,25 @@ bilibili_api.article
 专栏相关
 """
 
-from copy import copy
-import json
-from enum import Enum
-from typing import List, overload, Union
-
-import httpx
-from .utils.utils import get_api
-from .utils.Credential import Credential
-from .note import Note, NoteType
 import re
+import json
+from copy import copy
+from enum import Enum
 from html import unescape
-
-import yaml
-from yarl import URL
-from .utils.network_httpx import get_session, request
-from .exceptions.NetworkException import NetworkException, ApiException
-from bs4 import BeautifulSoup, element
 from datetime import datetime
 from urllib.parse import unquote
-from typing import TypeVar
+from typing import List, Union, TypeVar, overload
+
+import yaml
+import httpx
+from yarl import URL
+from bs4 import BeautifulSoup, element
+
+from .note import Note, NoteType
+from .utils.utils import get_api
+from .utils.credential import Credential
+from .utils.network_httpx import Api, get_session
+from .exceptions.NetworkException import ApiException, NetworkException
 
 API = get_api("article")
 
@@ -108,7 +107,7 @@ async def get_article_rank(
     """
     api = API["info"]["rank"]
     params = {"cid": rank_type.value}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 class ArticleList:
@@ -123,6 +122,7 @@ class ArticleList:
         """
         Args:
             rlid       (int)                        : 文集 id
+
             credential (Credential | None, optional): 凭据类. Defaults to None.
         """
         self.__rlid = rlid
@@ -142,7 +142,7 @@ class ArticleList:
 
         api = API["info"]["list"]
         params = {"id": self.__rlid}
-        return await request("GET", api["url"], params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
 
 class Article:
@@ -157,6 +157,7 @@ class Article:
         """
         Args:
             cvid       (int)                        : cv 号
+
             credential (Credential | None, optional): 凭据. Defaults to None.
         """
         self.__children: List[Node] = []
@@ -256,6 +257,7 @@ class Article:
     async def fetch_content(self) -> None:
         """
         获取并解析专栏内容
+
         该返回不会返回任何值，调用该方法后请再调用 `self.markdown()` 或 `self.json()` 来获取你需要的值。
         """
 
@@ -470,7 +472,7 @@ class Article:
                 elif e.name == "a":
                     # 超链接
                     if len(e.contents) == 0:
-                        from .utils.parse_link import parse_link, ResourceType
+                        from .utils.parse_link import ResourceType, parse_link
 
                         parse_link_res = await parse_link(e.attrs["href"])
                         if parse_link_res[1] == ResourceType.VIDEO:
@@ -505,7 +507,7 @@ class Article:
                     if not className:
                         # 图片
                         node = ImageNode()
-                        node.url = e.attrs.get("data-src")
+                        node.url = e.attrs.get("data-src")  # type: ignore
                         node_list.append(node)
 
                     elif "latex" in className:
@@ -537,6 +539,10 @@ class Article:
                         node = ImageNode()
                         node.url = field["insert"]["cut-off"]["url"]
                         self.__children.append(node)
+                    elif "native-image" in field["insert"].keys():
+                        node = ImageNode()
+                        node.url = field["insert"]["native-image"]["url"]
+                        self.__children.append(node)
                     else:
                         raise Exception()
                 else:
@@ -595,10 +601,7 @@ class Article:
 
         api = API["info"]["view"]
         params = {"id": self.__cvid}
-        resp = await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
-        return resp
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_all(self) -> dict:
         """
@@ -608,17 +611,24 @@ class Article:
             dict: 调用 API 返回的结果
         """
         sess = get_session()
-        resp = await sess.get(f"https://www.bilibili.com/read/cv{self.__cvid}")
-        html = resp.text
+        resp = await sess.get(
+            f"https://www.bilibili.com/read/cv{self.__cvid}",
+            headers={
+                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/111.0.0.0 Safari/537.36 Edg/111.0.1661.62",
+                "cookie": "opus-goback=1",
+            },
+        )
+        if resp.status_code == 200:
+            html = resp.text
 
-        match = re.search("window\.__INITIAL_STATE__=(\{.+?\});", html, re.I)  # type: ignore
+            match = re.search("window\.__INITIAL_STATE__=(\{.+?\});", html, re.I)  # type: ignore
 
-        if not match:
-            raise ApiException("找不到信息")
+            if not match:
+                raise ApiException("找不到信息")
 
-        data = json.loads(match[1])
+            data = json.loads(match[1])
 
-        return data
+            return data
 
     async def set_like(self, status: bool = True) -> dict:
         """
@@ -634,7 +644,7 @@ class Article:
 
         api = API["operate"]["like"]
         data = {"id": self.__cvid, "type": 1 if status else 2}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def set_favorite(self, status: bool = True) -> dict:
         """
@@ -653,7 +663,7 @@ class Article:
         )
 
         data = {"id": self.__cvid}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def add_coins(self) -> dict:
         """
@@ -667,7 +677,7 @@ class Article:
         upid = (await self.get_info())["mid"]
         api = API["operate"]["coin"]
         data = {"aid": self.__cvid, "multiply": 1, "upid": upid, "avtype": 2}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     # TODO: 专栏上传/编辑/删除
 
