@@ -4,13 +4,13 @@ bilibili_api.article_category
 专栏分类相关
 """
 import os
-from typing import List, Tuple, Optional
 import copy
 import json
-from .utils.network_httpx import request
-from .utils.utils import get_api
 from enum import Enum
+from typing import List, Tuple, Optional
 
+from .utils.utils import get_api
+from .utils.network_httpx import Api
 
 API = get_api("article-category")
 
@@ -136,8 +136,11 @@ async def get_category_recommend_articles(
 
     Args:
         category_id (int)         : 专栏分类的 id, 0 为全部. Defaults to 0.
+
         order       (ArticleOrder): 排序方式. Defaults to ArticleOrder.DEFAULT.
+
         page_num    (int)         : 页码. Defaults to 1.
+
         page_size   (int)         : 每一页数据大小. Defaults to 20.
 
     Returns:
@@ -145,4 +148,4 @@ async def get_category_recommend_articles(
     """
     api = API["info"]["recommends"]
     params = {"cid": category_id, "sort": order.value, "pn": page_num, "ps": page_size}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
