@@ -12,24 +12,20 @@ bilibili_api.bangumi
 
 import datetime
 from enum import Enum
-from typing import Any, Tuple, Union, List, Optional
+from typing import Any, List, Tuple, Union, Optional
 
 import requests
 
-from bilibili_api.utils.Danmaku import Danmaku
+from bilibili_api.utils.danmaku import Danmaku
 
 from . import settings
-
-from .utils.utils import get_api
-from .utils.initial_state import get_initial_state, get_initial_state_sync
-from .utils.Credential import Credential
-from .utils.network_httpx import get_session, request
-from .exceptions.ResponseException import ResponseException
-from .exceptions.ApiException import ApiException
 from .video import Video
-
-import json
-import re
+from .utils.utils import get_api
+from .utils.credential import Credential
+from .exceptions.ApiException import ApiException
+from .utils.network_httpx import request, Api, get_session
+from .exceptions.ResponseException import ResponseException
+from .utils.initial_state import get_initial_state, get_initial_state_sync
 
 API = get_api("bangumi")
 
@@ -74,7 +70,7 @@ async def get_timeline(type_: BangumiType, before: int = 7, after: int = 0) -> d
     """
     api = API["info"]["timeline"]
     params = {"types": type_.value, "before": before, "after": after}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 class IndexFilter:
@@ -190,8 +186,11 @@ class IndexFilter:
 
         Args:
             start (datetime, str, int): 开始时间. 如果是 None 则不设置开头.
+
             end   (datetime, str, int): 结束时间. 如果是 None 则不设置结尾.
+
             include_start (bool): 是否包含开始时间. 默认为 True.
+
             include_end   (bool): 是否包含结束时间. 默认为 False.
 
         Returns:
@@ -753,13 +752,21 @@ class IndexFilterMeta:
             Anime Meta
             Args:
                 version (Index_Filter.Version): 类型，如正片、电影等
+
                 spoken_language (Index_Filter.Spoken_Language): 配音
+
                 area (Index_Filter.Area): 地区
+
                 finish_status (Index_Filter.Finish_Status): 是否完结
+
                 copyright (Index_Filter.Copryright): 版权
+
                 payment (Index_Filter.Payment): 付费门槛
+
                 season (Index_Filter.Season): 季度
+
                 year (str): 年份，调用 Index_Filter.make_time_filter() 传入年份 (int, str) 获取
+
                 style (Index_Filter.Style.Anime): 风格
             """
             self.season_type = IndexFilter.Type.ANIME
@@ -785,9 +792,13 @@ class IndexFilterMeta:
             Movie Meta
             Args:
                 area (Index_Filter.Area): 地区
+
                 payment (Index_Filter.Payment): 付费门槛
+
                 season (Index_Filter.Season): 季度
+
                 release_date (str): 上映时间，调用 Index_Filter.make_time_filter() 传入年份 (datetime.datetime) 获取
+
                 style (Index_Filter.Style.Movie): 风格
             """
             self.season_type = IndexFilter.Type.MOVIE
@@ -808,8 +819,11 @@ class IndexFilterMeta:
             Documentary Meta
             Args:
                 area (Index_Filter.Area): 地区
+
                 release_date (str): 上映时间，调用 Index_Filter.make_time_filter() 传入年份 (datetime.datetime) 获取
+
                 style (Index_Filter.Style.Documentary): 风格
+
                 producer (Index_Filter.Producer): 制作方
             """
             self.season_type = IndexFilter.Type.DOCUMENTARY
@@ -830,8 +844,11 @@ class IndexFilterMeta:
             TV Meta
             Args:
                 area (Index_Filter.Area): 地区
+
                 payment (Index_Filter.Payment): 付费门槛
+
                 release_date (str): 上映时间，调用 Index_Filter.make_time_filter() 传入年份 (datetime.datetime) 获取
+
                 style (Index_Filter.Style.TV): 风格
             """
             self.season_type = IndexFilter.Type.TV
@@ -854,10 +871,15 @@ class IndexFilterMeta:
             Guochuang Meta
             Args:
                 version (Index_Filter.VERSION): 类型，如正片、电影等
+
                 finish_status (Index_Filter.Finish_Status): 是否完结
+
                 copyright (Index_Filter.Copyright): 版权
+
                 payment (Index_Filter.Payment): 付费门槛
+
                 year (str): 年份，调用 Index_Filter.make_time_filter() 传入年份 (int, str) 获取
+
                 style (Index_Filter.Style.GuoChuang): 风格
             """
             self.season_type = IndexFilter.Type.GUOCHUANG
@@ -878,6 +900,7 @@ class IndexFilterMeta:
             Variety Meta
             Args:
                 payment (Index_Filter.Payment): 付费门槛
+
                 style (Index_Filter.Style.Variety): 风格
             """
             self.season_type = IndexFilter.Type.VARIETY
@@ -899,9 +922,13 @@ async def get_index_info(
 
     Args:
         filters (Index_Filter_Meta, optional): 筛选条件元数据. Defaults to Anime.
+
         order (BANGUMI_INDEX.ORDER, optional): 排序字段. Defaults to SCORE.
+
         sort (BANGUMI_INDEX.SORT, optional): 排序方式. Defaults to DESC.
+
         pn (int, optional): 页数. Defaults to 1.
+
         ps (int, optional): 每页数量. Defaults to 20.
 
     Returns:
@@ -937,7 +964,7 @@ async def get_index_info(
     # params["type"] 未知参数，为 1
     params["type"] = 1
 
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 class Bangumi:
@@ -959,9 +986,13 @@ class Bangumi:
         """
         Args:
             media_id   (int, optional)              : 番剧本身的 ID. Defaults to -1.
+
             ssid       (int, optional)              : 每季度的 ID. Defaults to -1.
+
             epid       (int, optional)              : 每集的 ID. Defaults to -1.
+
             oversea    (bool, optional)             : 是否要采用兼容的港澳台Api,用于仅限港澳台地区番剧的信息请求. Defaults to False.
+
             credential (Credential | None, optional): 凭据类. Defaults to None.
         """
         if media_id == -1 and ssid == -1 and epid == -1:
@@ -1060,7 +1091,7 @@ class Bangumi:
 
         api = API["info"]["meta"]
         params = {"media_id": self.__media_id}
-        return await request("GET", api["url"], params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
     async def get_short_comment_list(
         self,
@@ -1072,6 +1103,7 @@ class Bangumi:
 
         Args:
             order      (BangumiCommentOrder, optional): 排序方式。Defaults to BangumiCommentOrder.DEFAULT
+
             next       (str | None, optional)         : 调用返回结果中的 next 键值，用于获取下一页数据。Defaults to None
 
         Returns:
@@ -1084,7 +1116,7 @@ class Bangumi:
         if next is not None:
             params["cursor"] = next
 
-        return await request("GET", api["url"], params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
     async def get_long_comment_list(
         self,
@@ -1096,6 +1128,7 @@ class Bangumi:
 
         Args:
             order      (BangumiCommentOrder, optional): 排序方式。Defaults to BangumiCommentOrder.DEFAULT
+
             next       (str | None, optional)         : 调用返回结果中的 next 键值，用于获取下一页数据。Defaults to None
 
         Returns:
@@ -1108,7 +1141,7 @@ class Bangumi:
         if next is not None:
             params["cursor"] = next
 
-        return await request("GET", api["url"], params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
     async def get_episode_list(self) -> dict:
         """
@@ -1132,7 +1165,7 @@ class Bangumi:
             )
             api = API["info"]["episodes_list"]
             params = {"season_id": self.__ssid}
-            return await request("GET", api["url"], params, credential=credential)
+            return await Api(**api, credential=credential).update_params(**params).result
 
     async def get_episodes(self) -> List["Episode"]:
         """
@@ -1144,7 +1177,10 @@ class Bangumi:
             return []
         first_epid = episode_list["main_section"]["episodes"][0]["id"]
         credential = self.credential if self.credential else Credential()
-        bangumi_meta = await get_initial_state(url=f"https://www.bilibili.com/bangumi/play/ep{first_epid}", credential=credential)
+        bangumi_meta = await get_initial_state(
+            url=f"https://www.bilibili.com/bangumi/play/ep{first_epid}",
+            credential=credential,
+        )
         bangumi_meta["media_id"] = self.get_media_id()
 
         episodes = []
@@ -1167,7 +1203,7 @@ class Bangumi:
 
         api = API["info"]["season_status"]
         params = {"season_id": self.__ssid}
-        return await request("GET", api["url"], params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
     async def get_overview(self) -> dict:
         """
@@ -1182,7 +1218,7 @@ class Bangumi:
         else:
             api = API["info"]["collective_info"]
         params = {"season_id": self.__ssid}
-        return await request("GET", api["url"], params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def set_follow(
@@ -1193,7 +1229,9 @@ async def set_follow(
 
     Args:
         bangumi    (Bangumi)                    : 番剧类
+
         status     (bool, optional)             : 追番状态. Defaults to True.
+
         credential (Credential | None, optional): 凭据. Defaults to None.
 
     Returns:
@@ -1204,7 +1242,7 @@ async def set_follow(
 
     api = API["operate"]["follow_add"] if status else API["operate"]["follow_del"]
     data = {"season_id": bangumi.get_season_id()}
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def update_follow_status(
@@ -1215,7 +1253,9 @@ async def update_follow_status(
 
     Args:
         bangumi    (Bangumi)                    : 番剧类
+
         credential (Credential | None, optional): 凭据. Defaults to None.
+
         status     (int)                        : 追番状态 1 想看 2 在看 3 已看
     Returns:
         dict: 调用 API 返回的结果
@@ -1225,7 +1265,7 @@ async def update_follow_status(
 
     api = API["operate"]["follow_status"]
     data = {"season_id": bangumi.get_season_id(), "status": status}
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 class Episode(Video):
@@ -1234,7 +1274,9 @@ class Episode(Video):
 
     Attributes:
         credential  (Credential): 凭据类
+
         video_class (Video)     : 视频类
+
         bangumi     (Bangumi)   : 所属番剧
     """
 
@@ -1242,6 +1284,7 @@ class Episode(Video):
         """
         Args:
             epid       (int)                 : 番剧 epid
+
             credential (Credential, optional): 凭据. Defaults to None.
         """
         global episode_data_cache
@@ -1249,7 +1292,10 @@ class Episode(Video):
         self.__epid = epid
 
         if not epid in episode_data_cache.keys():
-            content = get_initial_state_sync(url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}", credential=self.credential)
+            content = get_initial_state_sync(
+                url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
+                credential=self.credential,
+            )
         else:
             content = episode_data_cache[epid]["bangumi_meta"]
 
@@ -1304,7 +1350,10 @@ class Episode(Video):
         Returns:
             HTML 中的数据
         """
-        return await get_initial_state(url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}", credential=self.credential)
+        return await get_initial_state(
+            url=f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
+            credential=self.credential,
+        )
 
     async def get_bangumi_from_episode(self) -> "Bangumi":
         """
@@ -1324,7 +1373,7 @@ class Episode(Video):
         Returns:
             dict: 调用 API 返回的结果。
         """
-        url = API["info"]["playurl"]["url"]
+        api = API["info"]["playurl"]
         if True:
             params = {
                 "avid": self.get_aid(),
@@ -1334,7 +1383,7 @@ class Episode(Video):
                 "fnval": 4048,
                 "fourk": 1,
             }
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_danmaku_xml(self) -> str:
         """
