@@ -3,15 +3,16 @@ bilibili_api.channel
 
 频道相关，与视频分区不互通。
 """
-from bilibili_api.utils.initial_state import get_initial_state
-from bilibili_api.utils.network_httpx import request, get_session
-from bilibili_api.utils.utils import get_api
-from bilibili_api.utils.Credential import Credential
-from bilibili_api.errors import ResponseException, ApiException
 import re
 import json
 from enum import Enum
-from typing import Optional, List, Union
+from typing import List, Union, Optional
+
+from bilibili_api.utils.utils import get_api
+from bilibili_api.utils.credential import Credential
+from bilibili_api.utils.initial_state import get_initial_state
+from bilibili_api.errors import ApiException, ResponseException
+from bilibili_api.utils.network_httpx import request, Api
 
 API = get_api("channel")
 
@@ -24,7 +25,7 @@ async def get_channel_categories() -> dict:
         dict: 调用 API 返回的结果
     """
     api = API["categories"]["list"]
-    return await request("GET", api["url"])
+    return await Api(**api).result
 
 
 async def get_channel_category_detail(
@@ -35,12 +36,13 @@ async def get_channel_category_detail(
 
     Args:
         category_id (int): 频道分类的 id。
+
         offset      (str): 偏移值（下面的数据的第一个频道 ID，为该请求结果中的 offset 键对应的值），类似单向链表. Defaults to "0"
     """
     credential = credential if credential else Credential()
     api = API["categories"]["sub_channels"]
     params = {"id": category_id, "offset": offset}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 class ChannelVideosOrder(Enum):
@@ -122,6 +124,7 @@ class Channel:
 
         Args:
             info (list): 待筛选的数据
+
         Returns:
             list: card_type=achieve 的数据
         """
@@ -142,7 +145,9 @@ class Channel:
 
         Args:
             filter          (ChannelVideosFilter)       : 获取视频的相关选项. Defaults to ALL
+
             offset          (str)                       : 偏移值（下面的第一个视频的 ID，为该请求结果中的 offset 键对应的值），类似单向链表. Defaults to None
+
             page_size       (int)                       : 每页的数据大小. Defaults to 30
 
         Returns:
@@ -156,7 +161,7 @@ class Channel:
         if offset is not None:
             params["offset"] = offset
         params["page_size"] = page_size
-        info = await request("GET", api["url"], params=params)
+        info = await Api(**api).update_params(**params).result
 
         # 如果频道与番剧有关，会有番剧信息，需要排除掉 card_type=season 的数据
         info["list"] = self.only_achieve(info["list"])
@@ -173,7 +178,9 @@ class Channel:
 
         Args:
             order          (ChannelVideosOrder)         : 排序方式. Defaults to HOT
+
             offset         (str)                        : 偏移值（下面的第一个视频的 ID，为该请求结果中的 offset 键对应的值），类似单向链表
+
             page_size      (int)                        : 每页的数据大小
 
         Returns:
@@ -192,7 +199,7 @@ class Channel:
             params["offset"] = offset
         params["page_size"] = page_size
 
-        return await request("GET", api["url"], params=params)
+        return await Api(**api).update_params(**params).result
 
     async def get_list(
         self,
@@ -205,7 +212,9 @@ class Channel:
 
         Args:
             order          (ChannelVideosOrder)         : 排序方式. Defaults to HOT
+
             offset         (str)                        : 偏移值（下面的第一个视频的 ID，为该请求结果中的 offset 键对应的值），类似单向链表
+
             page_size      (int)                        : 每页的数据大小
 
         Returns:
@@ -270,7 +279,7 @@ async def get_self_subscribe_channels(credential: Credential) -> dict:
         dict: 调用 API 返回的结果
     """
     api = API["self_subscribes"]["list"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def subscribe_channel(channel: Channel, credential: Credential) -> dict:
@@ -279,14 +288,15 @@ async def subscribe_channel(channel: Channel, credential: Credential) -> dict:
 
     Args:
         channel    (Channel)   : 要订阅的频道
+
         credential (Credential): 凭据类
 
     Returns:
         dict: 调用 API 返回的结果
     """
     api = API["channel"]["subscribe"]
-    params = {"id": channel.get_channel_id()}
-    return await request("POST", api["url"], data=params, credential=credential)
+    data = {"id": channel.get_channel_id()}
+    return await Api(**api, credential=credential).update_data(data).result
 
 
 async def unsubscribe_channel(channel: Channel, credential: Credential) -> dict:
@@ -295,11 +305,12 @@ async def unsubscribe_channel(channel: Channel, credential: Credential) -> dict:
 
     Args:
         channel    (Channel)   : 要订阅的频道
+
         credential (Credential): 凭据类
 
     Returns:
         dict: 调用 API 返回的结果
     """
     api = API["channel"]["unsubscribe"]
-    params = {"id": channel.get_channel_id()}
-    return await request("POST", api["url"], data=params, credential=credential)
+    data = {"id": channel.get_channel_id()}
+    return await Api(**api, credential=credential).update_data(data).result
