@@ -3,14 +3,16 @@ bilibili_api.channel_series
 
 用户合集与列表相关
 """
-from enum import Enum
-from typing import Union, List, Optional
-from .utils.Credential import Credential
-from .utils.utils import get_api
-from .utils.network_httpx import request
 import json
+from enum import Enum
+from typing import List, Union, Optional
+
 import httpx
 
+from .utils.utils import get_api
+from .utils.credential import Credential
+from .utils.network_httpx import Api
+
 API_USER = get_api("user")
 API = get_api("channel-series")
 
@@ -60,8 +62,11 @@ class ChannelSeries:
         """
         Args:
             uid(int)                : 用户 uid. Defaults to -1.
+
             type_(ChannelSeriesType): 合集与列表类型. Defaults to ChannelSeriesType.SERIES.
+
             id_(int)                : season_id 或 series_id. Defaults to -1.
+
             credential(Credential)  : 凭证. Defaults to None.
         """
         global channel_meta_cache
@@ -111,7 +116,9 @@ class ChannelSeries:
         获取合集视频
         Args:
             sort(ChannelOrder): 排序方式
+
             pn(int)           : 页数，默认为 1
+
             ps(int)           : 每一页显示的视频数量
 
         Returns:
@@ -135,9 +142,13 @@ async def create_channel_series(
 
     Args:
         name (str): 列表名称。
+
         aids (List[int]): 要加入列表的视频的 aid 列表。
+
         keywords (List[str]): 列表的关键词。
+
         description (str): 列表的描述。
+
         credential (Credential | None): 凭据类。
 
     Returns:
@@ -157,7 +168,7 @@ async def create_channel_series(
         "keywords": ",".join(keywords),
         "description": description,
     }
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def del_channel_series(series_id: int, credential: Credential) -> dict:
@@ -166,12 +177,13 @@ async def del_channel_series(series_id: int, credential: Credential) -> dict:
 
     Args:
         series_id  (int)       : 旧版合集 id。
+
         credential (Credential): 凭据类。
 
     Returns:
         dict: 调用 API 返回的结果
     """
-    from .user import get_self_info, User
+    from .user import User, get_self_info
 
     credential.raise_for_no_sessdata()
     credential.raise_for_no_bili_jct()
@@ -193,7 +205,7 @@ async def del_channel_series(series_id: int, credential: Credential) -> dict:
         "series_id": series_id,
         "aids": ",".join(map(lambda x: str(x), aids)),
     }
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def add_aids_to_series(
@@ -204,7 +216,9 @@ async def add_aids_to_series(
 
     Args:
         series_id  (int)       : 旧版合集 id。
+
         aids       (List[int]) : 视频 aid 列表。
+
         credential (Credential): 凭据类。
 
     Returns:
@@ -221,7 +235,7 @@ async def add_aids_to_series(
         "series_id": series_id,
         "aids": ",".join(map(lambda x: str(x), aids)),
     }
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def del_aids_from_series(
@@ -232,7 +246,9 @@ async def del_aids_from_series(
 
     Args:
         series_id  (int)       : 旧版合集 id。
+
         aids       (List[int]) : 视频 aid 列表。
+
         credential (Credential): 凭据类。
 
     Returns:
@@ -249,7 +265,7 @@ async def del_aids_from_series(
         "series_id": series_id,
         "aids": ",".join(map(lambda x: str(x), aids)),
     }
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def set_follow_channel_season(
@@ -260,8 +276,9 @@ async def set_follow_channel_season(
 
     Args:
         season_id (int) : 合集 id
+
         status    (bool): 是否订阅状态. Defaults to True.
     """
     api = API["operate"]["fav"] if status else API["operate"]["unfav"]
     data = {"season_id": season_id}
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
