@@ -4,29 +4,28 @@ bilibili_api.cheese
 有关 bilibili 课程的 api。
 
 注意，注意！课程中的视频和其他视频几乎没有任何相通的 API！
+
 不能将 CheeseVideo 换成 Video 类。(CheeseVideo 类保留了所有的通用的 API)
 
 获取下载链接需要使用 bilibili_api.cheese.get_download_url，video.get_download_url 不适用。
+
 还有，课程的 season_id 和 ep_id 不与番剧相通，井水不犯河水，请不要错用!
 """
 
-import datetime
 import json
-from . import settings
+import datetime
+from typing import Any, List, Union
 
 import requests
-from .exceptions import (
-    DanmakuClosedException,
-    NetworkException,
-    ResponseException,
-)
-from .exceptions.ArgsException import ArgsException
-from .utils.BytesReader import BytesReader
-from .utils.Danmaku import Danmaku
-from .utils.Credential import Credential
+
+from . import settings
 from .utils.utils import get_api
-from .utils.network_httpx import get_session, request
-from typing import Any, List, Union
+from .utils.danmaku import Danmaku
+from .utils.credential import Credential
+from .utils.BytesReader import BytesReader
+from .exceptions.ArgsException import ArgsException
+from .utils.network_httpx import Api, get_session
+from .exceptions import NetworkException, ResponseException, DanmakuClosedException
 
 API = get_api("cheese")
 API_video = get_api("video")
@@ -52,7 +51,9 @@ class CheeseList:
         """
         Args:
             season_id  (int)       : ssid
+
             ep_id      (int)       : 单集 ep_id
+
             credential (Credential): 凭据类
 
         注意：season_id 和 ep_id 任选一个即可，两个都选的话
@@ -91,9 +92,7 @@ class CheeseList:
         """
         api = API["info"]["meta"]
         params = {"season_id": self.__season_id, "ep_id": self.__ep_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_list_raw(self):
         """
@@ -104,9 +103,7 @@ class CheeseList:
         """
         api = API["info"]["list"]
         params = {"season_id": self.__season_id, "pn": 1, "ps": 1000}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_list(self) -> List["CheeseVideo"]:
         """
@@ -118,9 +115,7 @@ class CheeseList:
         global cheese_video_meta_cache
         api = API["info"]["list"]
         params = {"season_id": self.__season_id, "pn": 1, "ps": 1000}
-        lists = await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        lists = await Api(**api, credential=self.credential).update_params(**params).result
         cheese_videos = []
         for c in lists["items"]:
             c["ssid"] = self.get_season_id()
@@ -136,6 +131,7 @@ class CheeseVideo:
 
     Attributes:
         credential (Credential): 凭据类
+
         cheese     (CheeseList): 所属的课程
     """
 
@@ -143,6 +139,7 @@ class CheeseVideo:
         """
         Args:
             epid      (int)       : 单集 ep_id
+
             credential (Credential): 凭据类
         """
         global cheese_video_meta_cache
@@ -217,9 +214,7 @@ class CheeseVideo:
             "fnval": 4048,
             "fourk": 1,
         }
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_stat(self) -> dict:
         """
@@ -228,9 +223,9 @@ class CheeseVideo:
         Returns:
             dict: 调用 API 返回的结果。
         """
-        url = API_video["info"]["stat"]["url"]
+        api = API_video["info"]["stat"]
         params = {"aid": self.get_aid()}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_pages(self) -> dict:
         """
@@ -239,9 +234,9 @@ class CheeseVideo:
         Returns:
             dict: 调用 API 返回的结果。
         """
-        url = API_video["info"]["pages"]["url"]
+        api = API_video["info"]["pages"]
         params = {"aid": self.get_aid()}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_danmaku_view(self) -> dict:
         """
@@ -516,6 +511,15 @@ class CheeseVideo:
                     if type_ == 4:
                         reader.bytes_string()
                         # 什么鬼？我用 protoc 解析出乱码！
+                    elif type_ == 5:
+                        # 大会员专属颜色
+                        reader.varint()
+                        reader.varint()
+                        reader.varint()
+                        reader.bytes_string()
+                    elif type_ == 13:
+                        # ???
+                        continue
                     else:
                         raise ResponseException("解析响应数据错误")
 
@@ -552,6 +556,14 @@ class CheeseVideo:
                         dm.id_str = dm_reader.string()
                     elif data_type == 13:
                         dm.attr = dm_reader.varint()
+                    elif data_type == 14:
+                        dm.uid = dm_reader.varint()
+                    elif data_type == 15:
+                        dm_reader.varint()
+                    elif data_type == 20:
+                        dm_reader.bytes_string()
+                    elif data_type == 21:
+                        dm_reader.bytes_string()
                     else:
                         break
                 danmakus.append(dm)
@@ -614,9 +626,7 @@ class CheeseVideo:
             "mode": danmaku.mode,
             "plat": 1,
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(data).result
 
     async def has_liked(self):
         """
@@ -627,9 +637,9 @@ class CheeseVideo:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = get_api("video")["info"]["has_liked"]["url"]
+        api =API_video["info"]["has_liked"]
         params = {"aid": self.get_aid()}
-        return await request("GET", url, params=params, credential=self.credential) == 1
+        return await Api(**api, credential=self.credential).update_params(**params).result == 1
 
     async def get_pay_coins(self):
         """
@@ -640,9 +650,9 @@ class CheeseVideo:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = get_api("video")["info"]["get_pay_coins"]["url"]
+        api =API_video["info"]["get_pay_coins"]
         params = {"aid": self.get_aid()}
-        return (await request("GET", url, params=params, credential=self.credential))[
+        return (await Api(**api, credential=self.credential).update_params(**params).result)[
             "multiply"
         ]
 
@@ -655,9 +665,9 @@ class CheeseVideo:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = get_api("video")["info"]["has_favoured"]["url"]
+        api =API_video["info"]["has_favoured"]
         params = {"aid": self.get_aid()}
-        return (await request("GET", url, params=params, credential=self.credential))[
+        return (await Api(**api, credential=self.credential).update_params(**params).result)[
             "favoured"
         ]
 
@@ -674,11 +684,9 @@ class CheeseVideo:
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
 
-        api = get_api("video")["operate"]["like"]
+        api = API_video["operate"]["like"]
         data = {"aid": self.get_aid(), "like": 1 if status else 2}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(data).result
 
     async def pay_coin(self, num: int = 1, like: bool = False):
         """
@@ -686,6 +694,7 @@ class CheeseVideo:
 
         Args:
             num  (int, optional) : 硬币数量，为 1 ~ 2 个。Defaults to 1.
+
             like (bool, optional): 是否同时点赞。Defaults to False.
 
         Returns:
@@ -697,15 +706,13 @@ class CheeseVideo:
         if num not in (1, 2):
             raise ArgsException("投币数量只能是 1 ~ 2 个。")
 
-        api = get_api("video")["operate"]["coin"]
+        api = API_video["operate"]["coin"]
         data = {
             "aid": self.get_aid(),
             "multiply": num,
             "like": 1 if like else 0,
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(data).result
 
     async def set_favorite(
         self, add_media_ids: List[int] = [], del_media_ids: List[int] = []
@@ -715,6 +722,7 @@ class CheeseVideo:
 
         Args:
             add_media_ids (List[int], optional): 要添加到的收藏夹 ID. Defaults to [].
+
             del_media_ids (List[int], optional): 要移出的收藏夹 ID. Defaults to [].
 
         Returns:
@@ -726,16 +734,14 @@ class CheeseVideo:
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
 
-        api = get_api("video")["operate"]["favorite"]
+        api = API_video["operate"]["favorite"]
         data = {
             "rid": self.get_aid(),
             "type": 2,
             "add_media_ids": ",".join(map(lambda x: str(x), add_media_ids)),
             "del_media_ids": ",".join(map(lambda x: str(x), del_media_ids)),
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(data).result
 
     async def get_danmaku_xml(self):
         """
