@@ -16,11 +16,10 @@ from enum import Enum
 from typing import Union
 
 from .utils.utils import get_api
-from .utils.network_httpx import request
-from .utils.Credential import Credential
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 from .exceptions.ArgsException import ArgsException
 
-
 API = get_api("common")
 
 
@@ -80,8 +79,11 @@ class Comment:
         """
         Args:
             oid        (int)         : 评论所在资源 ID。
+
             type_      (ResourceType): 评论所在资源类型枚举。
+
             rpid       (int)         : 评论 ID。
+
             credential (Credential)  : 凭据类. Defaults to None.
         """
         self.__oid = oid
@@ -130,9 +132,7 @@ class Comment:
         self.credential.raise_for_no_bili_jct()
 
         api = API["comment"]["like"]
-        return await request(
-            "POST", api["url"], data=self.__get_data(status), credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**self.__get_data(status)).result
 
     async def hate(self, status: bool = True) -> dict:
         """
@@ -149,9 +149,7 @@ class Comment:
         self.credential.raise_for_no_bili_jct()
 
         api = API["comment"]["hate"]
-        return await request(
-            "POST", api["url"], data=self.__get_data(status), credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**self.__get_data(status)).result
 
     async def pin(self, status: bool = True) -> dict:
         """
@@ -167,9 +165,7 @@ class Comment:
         self.credential.raise_for_no_bili_jct()
 
         api = API["comment"]["pin"]
-        return await request(
-            "POST", api["url"], data=self.__get_data(status), credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**self.__get_data(status)).result
 
     async def delete(self) -> dict:
         """
@@ -184,7 +180,7 @@ class Comment:
         api = API["comment"]["del"]
         data = self.__get_data(True)
         del data["action"]
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_sub_comments(self, page_index: int = 1) -> dict:
         """
@@ -208,9 +204,7 @@ class Comment:
             "root": self.__rpid,
         }
 
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
 
 async def send_comment(
@@ -234,10 +228,15 @@ async def send_comment(
 
     Args:
         text       (str)          : 评论内容。
+
         oid        (str)          : 资源 ID。
+
         type_      (CommentsResourceType) : 资源类型枚举。
+
         root       (int, optional): 根评论 ID, Defaults to None.
+
         parent     (int, optional): 父评论 ID, Defaults to None.
+
         credential (Credential)   : 凭据
 
     Returns:
@@ -272,7 +271,7 @@ async def send_comment(
         raise ArgsException("root=None 时，parent 不得设置")
 
     api = API["comment"]["send"]
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def get_comments(
@@ -281,15 +280,19 @@ async def get_comments(
     page_index: int = 1,
     order: OrderType = OrderType.TIME,
     credential: Union[Credential, None] = None,
-):
+) -> dict:
     """
     获取资源评论列表。
 
     Args:
         oid        (int)                 : 资源 ID。
+
         type_      (CommentsResourceType)        : 资源类枚举。
+
         page_index (int, optional)       : 页码. Defaults to 1.
+
         order      (OrderType, optional) : 排序方式枚举. Defaults to OrderType.TIME.
+
         credential (Credential, optional): 凭据。Defaults to None.
 
     Returns:
@@ -300,4 +303,4 @@ async def get_comments(
 
     api = API["comment"]["get"]
     params = {"pn": page_index, "type": type_.value, "oid": oid, "sort": order.value}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
