@@ -7,11 +7,11 @@ bilibili_api.creative_center
 """
 
 from enum import Enum
-from typing import Union, List
+from typing import List, Union
 
 from .utils.utils import get_api
-from .utils.network_httpx import request
-from .utils.Credential import Credential
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 
 API = get_api("creative_center")
 
@@ -139,7 +139,7 @@ async def get_compare(credential: Credential) -> dict:
         dict: 视频对比数据。
     """
     api = API["overview"]["compare"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_graph(
@@ -152,7 +152,9 @@ async def get_graph(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         period      (GraphPeriod): 时间段。
+
         graph_type  (GraphType):   图表类型。
 
     Returns:
@@ -164,7 +166,7 @@ async def get_graph(
         "s_locale": "zh_CN",
         "type": graph_type.value,
     }
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_overview(
@@ -175,6 +177,7 @@ async def get_overview(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         period      (GraphPeriod): 时间段。
 
     Returns:
@@ -183,7 +186,7 @@ async def get_overview(
     api = API["overview"]["num"]
     # 不知道 tab 的作用是什么，但是不传会报错
     params = {"period": period.value, "s_locale": "zh_CN", "tab": 0}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_video_survey(credential: Credential) -> dict:
@@ -198,7 +201,7 @@ async def get_video_survey(credential: Credential) -> dict:
     """
     api = API["video"]["survey"]
     params = {"type": 1}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_video_playanalysis(
@@ -209,6 +212,7 @@ async def get_video_playanalysis(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         copyright   (Copyright):   版权类型。
 
     Returns:
@@ -216,7 +220,7 @@ async def get_video_playanalysis(
     """
     api = API["video"]["playanalysis"]
     params = {"copyright": copyright.value}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_video_source(credential: Credential) -> dict:
@@ -231,7 +235,7 @@ async def get_video_source(credential: Credential) -> dict:
     """
     api = API["video"]["source"]
     params = {"s_locale": "zh_CN"}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_fan_overview(
@@ -242,6 +246,7 @@ async def get_fan_overview(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         period      (FanGraphPeriod): 时间段。
 
     Returns:
@@ -249,7 +254,7 @@ async def get_fan_overview(
     """
     api = API["fan"]["overview"]
     params = {"period": period.value}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_fan_graph(
@@ -262,7 +267,9 @@ async def get_fan_graph(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         period      (FanGraphPeriod): 时间段。
+
         graph_type  (FanGraphType):   图表类型。
 
     Returns:
@@ -270,7 +277,7 @@ async def get_fan_graph(
     """
     api = API["fan"]["graph"]
     params = {"period": period.value, "type": graph_type.value}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_article_overview(credential: Credential) -> dict:
@@ -284,7 +291,7 @@ async def get_article_overview(credential: Credential) -> dict:
         dict: 文章概览数据。
     """
     api = API["article"]["overview"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_article_graph(
@@ -295,6 +302,7 @@ async def get_article_graph(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         graph_type  (ArticleInfoType):   图表类型。
 
     Returns:
@@ -303,7 +311,7 @@ async def get_article_graph(
 
     api = API["article"]["graph"]
     params = {"type": graph_type.value}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_article_rank(
@@ -314,6 +322,7 @@ async def get_article_rank(
 
     Args:
         credentials (Credential): Credential 凭据。
+
         rank_type  (ArticleInfoType):   排行依据。
 
     Returns:
@@ -322,7 +331,7 @@ async def get_article_rank(
 
     api = API["article"]["rank"]
     params = {"type": rank_type.value}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_article_source(credential: Credential) -> dict:
@@ -337,4 +346,4 @@ async def get_article_source(credential: Credential) -> dict:
     """
 
     api = API["article"]["source"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
