@@ -4,11 +4,12 @@ bilibili_api.game
 游戏相关
 """
 
-from .utils.network_httpx import request
-from .utils.Credential import Credential
-from .utils.utils import get_api
 from typing import Union
 
+from .utils.utils import get_api
+from .utils.credential import Credential
+from .utils.network_httpx import Api
+
 API = get_api("game")
 
 
@@ -24,6 +25,7 @@ class Game:
         """
         Args:
             game_id    (int)       : 游戏 id
+
             credential (Credential): 凭据类. Defaults to None.
         """
         self.__game_id = game_id
@@ -41,9 +43,7 @@ class Game:
         """
         api = API["info"]["info"]
         params = {"game_base_id": self.__game_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_up_info(self) -> dict:
         """
@@ -54,9 +54,7 @@ class Game:
         """
         api = API["info"]["UP"]
         params = {"game_base_id": self.__game_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_detail(self) -> dict:
         """
@@ -67,9 +65,7 @@ class Game:
         """
         api = API["info"]["detail"]
         params = {"game_base_id": self.__game_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_wiki(self) -> dict:
         """
@@ -80,9 +76,7 @@ class Game:
         """
         api = API["info"]["wiki"]
         params = {"game_base_id": self.__game_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_videos(self) -> dict:
         """
@@ -93,9 +87,7 @@ class Game:
         """
         api = API["info"]["videos"]
         params = {"game_base_id": self.__game_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     # async def get_score(self) -> dict:
     #     """
