@@ -4,8 +4,8 @@ bilibili_api.hot
 热门相关 API
 """
 
-from .utils.network_httpx import request
 from .utils.utils import get_api
+from .utils.network_httpx import Api
 
 API_rank = get_api("rank")
 API = get_api("hot")
@@ -17,6 +17,7 @@ async def get_hot_videos(pn: int = 1, ps: int = 20) -> dict:
 
     Args:
         pn (int): 第几页. Default to 1.
+
         ps (int): 每页视频数. Default to 20.
 
     Returns:
@@ -24,7 +25,7 @@ async def get_hot_videos(pn: int = 1, ps: int = 20) -> dict:
     """
     api = API_rank["info"]["hot"]
     params = {"ps": ps, "pn": pn}
-    return await request("GET", url=api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def get_weakly_hot_videos_list() -> dict:
@@ -35,7 +36,7 @@ async def get_weakly_hot_videos_list() -> dict:
         调用 API 返回的结果
     """
     api = API_rank["info"]["weakly_series"]
-    return await request("GET", url=api["url"])
+    return await Api(**api).result
 
 
 async def get_weakly_hot_videos(week: int = 1) -> dict:
@@ -50,7 +51,7 @@ async def get_weakly_hot_videos(week: int = 1) -> dict:
     """
     api = API_rank["info"]["weakly_details"]
     params = {"number": week}
-    return await request("GET", url=api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def get_history_popular_videos() -> dict:
@@ -62,7 +63,7 @@ async def get_history_popular_videos() -> dict:
     """
     api = API_rank["info"]["history_popular"]
     params = {"page_size": 85, "page": 1}
-    return await request("GET", url=api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def get_hot_buzzwords(page_num: int = 1, page_size: int = 20) -> dict:
@@ -71,6 +72,7 @@ async def get_hot_buzzwords(page_num: int = 1, page_size: int = 20) -> dict:
 
     Args:
         page_num  (int): 页码. Defaults to 1.
+
         page_size (int): 每一页的数据大小. Defaults to 20.
 
     Returns:
@@ -78,4 +80,4 @@ async def get_hot_buzzwords(page_num: int = 1, page_size: int = 20) -> dict:
     """
     api = API["buzzwords"]
     params = {"pn": page_num, "ps": page_size, "type_id": 4}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
