@@ -6,25 +6,26 @@ bilibili_api.interactive_video
 
 # pylint: skip-file
 
-from asyncio import CancelledError, create_task
+import os
 import copy
 import enum
 import json
-import os
-import shutil
 import time
-from typing import Callable, List, Tuple, Union
-from .utils.Credential import Credential
-from .utils.utils import get_api
-from .utils.network_httpx import request
-from .video import Video
+import shutil
+import zipfile
 from urllib import parse
 from random import randint as rand
+from asyncio import CancelledError, create_task
+from typing import List, Tuple, Union, Callable, Coroutine
+
 import requests
+
 from . import settings
-import zipfile
+from .video import Video
+from .utils.utils import get_api
 from .utils.AsyncEvent import AsyncEvent
-from typing import Coroutine
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 
 API = get_api("interactive_video")
 
@@ -92,9 +93,13 @@ class InteractiveVariable:
         """
         Args:
             name      (str)  : 变量名
+
             var_id    (str)  : 变量 id
+
             var_value (int)  : 变量的值
+
             show      (bool) : 是否显示
+
             random    (bool) : 是否为随机值(1-100)
         """
         self.__var_id = var_id
@@ -144,8 +149,11 @@ class InteractiveButton:
         """
         Args:
             text  (str)                         : 文字
+
             x     (int)                         : x 轴
+
             y     (int)                         : y 轴
+
             align (InteractiveButtonAlign | int): 按钮的文字在按钮中的位置
         """
         self.__text = text
@@ -176,6 +184,7 @@ class InteractiveJumpingCondition:
         """
         Args:
             var       (List[InteractiveVariable]): 所有变量
+
             condition (str)                      : 公式
         """
         self.__vars = var
@@ -217,6 +226,7 @@ class InteractiveJumpingCommand:
         """
         Args:
             var       (List[InteractiveVariable]): 所有变量
+
             command   (str)                      : 公式
         """
         self.__vars = var
@@ -264,12 +274,19 @@ class InteractiveNode:
         """
         Args:
             video          (InteractiveVideo)           : 视频类
+
             node_id        (int)                        : 节点 id
+
             cid            (int)                        : CID
+
             vars           (List[InteractiveVariable])  : 变量
+
             button         (InteractiveButton)          : 对应的按钮
+
             condition      (InteractiveJumpingCondition): 跳转公式
+
             native_command (InteractiveJumpingCommand)  : 跳转时变量操作
+
             is_default     (bool)                       : 是不是默认的跳转的节点
         """
         self.__parent = video
@@ -459,9 +476,9 @@ class InteractiveVideo(Video):
             dict: 调用 API 返回的结果
         """
         credential = self.credential if self.credential else Credential()
-        url = API["info"]["videolist"]["url"]
+        api = API["info"]["videolist"]
         params = {"bvid": self.get_bvid()}
-        return await request("GET", url=url, params=params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
     async def up_submit_story_tree(self, story_tree: str) -> dict:
         """
@@ -474,7 +491,7 @@ class InteractiveVideo(Video):
             dict: 调用 API 返回的结果
         """
         credential = self.credential if self.credential else Credential()
-        url = API["operate"]["savestory"]["url"]
+        api = API["operate"]["savestory"]
         form_data = {"preview": "0", "data": story_tree, "csrf": credential.bili_jct}
         headers = {
             "User-Agent": "Mozilla/5.0",
@@ -484,15 +501,9 @@ class InteractiveVideo(Video):
             "Accept": "application/json, text/plain, */*",
         }
         data = parse.urlencode(form_data)
-        return await request(
-            "POST",
-            url=url,
-            data=data,
-            headers=headers,
-            no_csrf=True,
-            credential=credential,
-        )
-
+        return await Api(**api, credential=credential, no_csrf=True
+                         ).update_data(**data).update_headers(**headers).result
+    
     async def get_graph_version(self) -> int:
         """
         获取剧情图版本号，仅供 `get_edge_info()` 使用。
@@ -511,7 +522,7 @@ class InteractiveVideo(Video):
         api = "https://api.bilibili.com/x/player/v2"
         params = {"bvid": bvid, "cid": cid}
 
-        resp = await request("GET", api, params, credential=credential)
+        resp = await Api(**api, credential=credential).update_params(**params).result
         return resp["interaction"]["graph_version"]
 
     async def get_edge_info(self, edge_id: Union[int, None] = None):
@@ -527,13 +538,13 @@ class InteractiveVideo(Video):
         bvid = self.get_bvid()
         credential = self.credential if self.credential is not None else Credential()
 
-        url = API["info"]["edge_info"]["url"]
+        api = API["info"]["edge_info"]
         params = {"bvid": bvid, "graph_version": (await self.get_graph_version())}
 
         if edge_id is not None:
             params["edge_id"] = edge_id
 
-        return await request("GET", url, params, credential=credential)
+        return await Api(**api, credential=credential).update_params(**params).result
 
     async def mark_score(self, score: int = 5):
         """
@@ -549,7 +560,7 @@ class InteractiveVideo(Video):
         self.credential.raise_for_no_bili_jct()
         api = API["operate"]["mark_score"]
         data = {"mark": score, "bvid": self.get_bvid()}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_cid(self) -> int:
         """
@@ -629,8 +640,11 @@ class InteractiveVideoDownloader(AsyncEvent):
         """
         Args:
             video              (InteractiveVideo)              : 互动视频类
+
             out                (str)                           : 输出文件地址 (如果模式为 NODE_VIDEOS/NO_PACKAGING 则此参数表示所有节点视频的存放目录)
+
             self_download_func (Coroutine | None)              : 自定义下载函数（需 async 函数）
+
             downloader_mode    (InteractiveVideoDownloaderMode): 下载模式
 
         `self_download_func` 函数应接受两个参数（第一个是下载 URL，第二个是输出地址（精确至文件名））
@@ -845,7 +859,7 @@ class InteractiveVideoDownloader(AsyncEvent):
                 url = await self.__video.get_download_url(cid=cid, html5=True)
                 await self.__download_func(
                     url["durl"][0]["url"],
-                    tmp_dir_name + "/" + str(key) + " " + item["title"] + ".mp4",
+                    tmp_dir_name + "/" + str(cid) + ".mp4",
                 )  # type: ignore
 
         root_cid = await self.__video.get_cid()
@@ -855,7 +869,7 @@ class InteractiveVideoDownloader(AsyncEvent):
             url = await self.__video.get_download_url(cid=cid, html5=True)
             title = (await self.__video.get_info())["title"]
             await self.__download_func(
-                url["durl"][0]["url"], tmp_dir_name + "/1 " + title + ".mp4"
+                url["durl"][0]["url"], tmp_dir_name + "/" + str(cid) + ".mp4"
             )  # type: ignore
 
         self.dispatch("PACKAGING")
