@@ -4,20 +4,21 @@ bilibili_api.note
 笔记相关
 """
 
-from html import unescape
+import re
 import json
 from enum import Enum
-
-from yarl import URL
-from .utils.utils import get_api
-from .utils.Credential import Credential
-from .utils.network_httpx import request, get_session
-from .exceptions import ArgsException, ApiException
-from .utils.Picture import Picture
+from html import unescape
 from typing import List, Union, overload
-import httpx
-import re
+
 import yaml
+import httpx
+from yarl import URL
+
+from .utils.utils import get_api
+from .utils.picture import Picture
+from .utils.credential import Credential
+from .exceptions import ApiException, ArgsException
+from .utils.network_httpx import Api, get_session
 
 API = get_api("note")
 API_ARTICLE = get_api("article")
@@ -44,9 +45,13 @@ class Note:
         """
         Args:
             cvid       (int)                  : 公开笔记 ID (对应专栏的 cvid) (公开笔记必要)
+
             aid        (int)                  : 稿件 ID（oid_type 为 0 时是 avid） (私有笔记必要)
+
             note_id    (int)                  : 私有笔记 ID (私有笔记必要)
+
             note_type  (str)                  : 笔记类型 (private, public)
+
             credential (Credential, optional) : Credential. Defaults to None.
         """
         self.__oid = -1
@@ -125,9 +130,7 @@ class Note:
         api = API["private"]["detail"]
         # oid 为 0 时指 avid
         params = {"oid": self.get_aid(), "note_id": self.get_note_id(), "oid_type": 0}
-        resp = await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        resp = await Api(**api, credential=self.credential).update_params(**params).result
         # 存入 self.__info 中以备后续调用
         self.__info = resp
         return resp
@@ -144,9 +147,7 @@ class Note:
 
         api = API["public"]["detail"]
         params = {"cvid": self.get_cvid()}
-        resp = await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        resp = await Api(**api, credential=self.credential).update_params(**params).result
         # 存入 self.__info 中以备后续调用
         self.__info = resp
         return resp
@@ -224,7 +225,7 @@ class Note:
 
         api = API_ARTICLE["operate"]["like"]
         data = {"id": self.__cvid, "type": 1 if status else 2}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def set_favorite(self, status: bool = True) -> dict:
         """
@@ -249,7 +250,7 @@ class Note:
         )
 
         data = {"id": self.__cvid}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def add_coins(self) -> dict:
         """
@@ -267,11 +268,12 @@ class Note:
         upid = (await self.get_info())["mid"]
         api = API_ARTICLE["operate"]["coin"]
         data = {"aid": self.__cvid, "multiply": 1, "upid": upid, "avtype": 2}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def fetch_content(self) -> None:
         """
         获取并解析笔记内容
+
         该返回不会返回任何值，调用该方法后请再调用 `self.markdown()` 或 `self.json()` 来获取你需要的值。
         """
 
