@@ -3,12 +3,13 @@ bilibili_api.search
 
 搜索
 """
-from enum import Enum
-from typing import Callable, Union, List
 import json
+from enum import Enum
+from typing import List, Union, Callable
+
 from .utils.utils import get_api
-from .utils.network_httpx import request, get_session
 from .video_zone import VideoZoneTypes
+from .utils.network_httpx import Api, get_session
 
 API = get_api("search")
 
@@ -155,6 +156,7 @@ async def search(keyword: str, page: int = 1) -> dict:
 
     Args:
         keyword (str): 搜索关键词
+
         page    (int): 页码. Defaults to 1.
 
     Returns:
@@ -162,7 +164,7 @@ async def search(keyword: str, page: int = 1) -> dict:
     """
     api = API["search"]["web_search"]
     params = {"keyword": keyword, "page": page}
-    return await request("GET", url=api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def search_by_type(
@@ -182,13 +184,21 @@ async def search_by_type(
 
     Args:
         debug_param_func (Callable | None, optional)                                             : 参数回调器，用来存储或者什么的
+
         order_sort       (int | None, optional)                                                  : 用户粉丝数及等级排序顺序 默认为0 由高到低：0 由低到高：1
+
         category_id      (CategoryTypeArticle | CategoryTypePhoto | int | None, optional)        : 专栏/相簿分区筛选，指定分类，只在相册和专栏类型下生效
+
         time_range       (int, optional)                                                         : 指定时间，自动转换到指定区间，只在视频类型下生效 有四种：10分钟以下，10-30分钟，30-60分钟，60分钟以上
+
         video_zone_type        (int | ZoneTypes | None, optional)                                : 话题类型，指定 tid (可使用 channel 模块查询)
+
         order_type       (OrderUser | OrderLiveRoom | OrderArticle | OrderVideo | None, optional): 排序分类类型
+
         keyword          (str)                                                                   : 搜索关键词
+
         search_type      (SearchObjectType | None, optional)                                     : 搜索类型
+
         page             (int, optional)                                                         : 页码
 
     Returns:
@@ -240,7 +250,7 @@ async def search_by_type(
     if debug_param_func:
         debug_param_func(params)
     api = API["search"]["web_search_by_type"]
-    return await request("GET", url=api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def get_default_search_keyword() -> dict:
@@ -251,7 +261,7 @@ async def get_default_search_keyword() -> dict:
         dict: 调用 API 返回的结果
     """
     api = API["search"]["default_search_keyword"]
-    return await request("GET", api["url"])
+    return await Api(**api).result
 
 
 async def get_hot_search_keywords() -> dict:
@@ -299,7 +309,7 @@ async def search_games(keyword: str) -> dict:
     """
     api = API["search"]["game"]
     params = {"keyword": keyword}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def search_manga(keyword: str, page_num: int = 1, page_size: int = 9):
@@ -308,7 +318,9 @@ async def search_manga(keyword: str, page_num: int = 1, page_size: int = 9):
 
     Args:
         keyword   (str): 搜索关键词
+
         page_num  (int): 页码. Defaults to 1.
+
         page_size (int): 每一页的数据大小. Defaults to 9.
 
     Returns:
@@ -316,7 +328,7 @@ async def search_manga(keyword: str, page_num: int = 1, page_size: int = 9):
     """
     api = API["search"]["manga"]
     data = {"key_word": keyword, "page_num": page_num, "page_size": page_size}
-    return await request("POST", api["url"], data=data, no_csrf=True)
+    return await Api(**api, no_csrf=True).update_data(**data).result
 
 
 async def search_cheese(
@@ -330,8 +342,11 @@ async def search_cheese(
 
     Args:
         keyword   (str)        : 搜索关键词
+
         page_num  (int)        : 页码. Defaults to 1.
+
         page_size (int)        : 每一页的数据大小. Defaults to 30.
+
         order     (OrderCheese): 排序方式. Defaults to OrderCheese.RECOMMEND
 
     Returns:
@@ -344,4 +359,4 @@ async def search_cheese(
         "page_size": page_size,
         "sort_type": order.value,
     }
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
