@@ -4,18 +4,17 @@ bilibili_api.user
 用户相关
 """
 
-from enum import Enum
 import json
-from json.decoder import JSONDecodeError
 import time
+from enum import Enum
+from typing import List, Union, Tuple
+from json.decoder import JSONDecodeError
 
-from .exceptions import ResponseCodeException
-
-from .utils.network_httpx import get_session, request
 from .utils.utils import get_api, join
-from .utils.Credential import Credential
+from .utils.credential import Credential
+from .exceptions import ResponseCodeException
+from .utils.network_httpx import get_session, Api
 from .channel_series import ChannelOrder, ChannelSeries, ChannelSeriesType
-from typing import List, Union
 
 API = get_api("user")
 
@@ -122,6 +121,64 @@ class RelationType(Enum):
     REMOVE_FANS = 7
 
 
+class BangumiFollowStatus(Enum):
+    """
+    番剧追番状态类型。
+
+    + ALL        : 全部
+    + WANT       : 想看
+    + WATCHING   : 在看
+    + WATCHED    : 已看
+    """
+
+    ALL = 0
+    WANT = 1
+    WATCHING = 2
+    WATCHED = 3
+
+class HistoryType(Enum):
+    """
+    历史记录分类
+
+    + ALL      : 全部
+    + archive  : 稿件
+    + live     : 直播
+    + article  : 专栏
+    """
+
+    ALL = "all"
+    archive = "archive"
+    live = "live"
+    article = "article"
+
+
+class HistoryBusinessType(Enum):
+    """
+    历史记录 Business 分类
+
+    + archive：稿件
+    + pgc：剧集（番剧 / 影视）
+    + live：直播
+    + article-list：文集
+    + article：文章
+    """
+
+    archive = "archive"
+    pgc = "pgc"
+    live = "live"
+    article_list = "article-list"
+    article = "article"
+
+class OrderType(Enum):
+    """
+    排序字段
+
+    + desc：倒序
+    + asc：正序
+    """
+    desc = "desc"
+    asc = "asc"
+
 async def name2uid(names: Union[str, List[str]]):
     """
     将用户名转为 uid
@@ -132,13 +189,12 @@ async def name2uid(names: Union[str, List[str]]):
     Returns:
         dict: 调用 API 返回的结果
     """
-    api = API["info"]["name_to_uid"]
     if isinstance(names, str):
         n = names
     else:
         n = ",".join(names)
     params = {"names": n}
-    return await request("GET", api["url"], params=params)
+    return await Api(**API["info"]["name_to_uid"]).update_params(**params).result
 
 
 class User:
@@ -150,6 +206,7 @@ class User:
         """
         Args:
             uid        (int)                        : 用户 UID
+
             credential (Credential | None, optional): 凭据. Defaults to None.
         """
         self.__uid = uid
@@ -165,17 +222,13 @@ class User:
 
         Returns:
             dict: 调用接口返回的内容。
+
+        [用户空间详细信息](https://github.com/SocialSisterYi/bilibili-API-collect/blob/master/docs/user/info.md#%E7%94%A8%E6%88%B7%E7%A9%BA%E9%97%B4%E8%AF%A6%E7%BB%86%E4%BF%A1%E6%81%AF)
         """
-        api = API["info"]["info"]
         params = {
             "mid": self.__uid,
-            "token": "",
-            "platform": "web",
-            "web_location": 1550101
         }
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**API["info"]["info"], credential=self.credential).update_params(**params).result
 
     async def __get_self_info(self) -> dict:
         """
@@ -187,43 +240,32 @@ class User:
         if self.__self_info is not None:
             return self.__self_info
 
-        self.__self_info = await get_self_info(credential=self.credential)
+        self.__self_info = await self.get_user_info()
         return self.__self_info
 
     def get_uid(self) -> int:
+        """
+        获取用户 UID
+
+        Returns:
+            int: 用户 UID
+        """
         return self.__uid
 
-    async def get_user_fav_tag(self) -> dict:
+    async def get_user_fav_tag(self, pn: int = 1, ps: int = 20) -> dict:
         """
         获取用户关注的 Tag 信息，如果用户设为隐私，则返回 获取登录数据失败
 
+        Args:
+            pn (int, optional): 页码，从 1 开始. Defaults to 1.
+            ps (int, optional): 每页的数据量. Defaults to 20.
+
         Returns:
             dict: 调用接口返回的内容。
         """
-        # (未打包至 utils 的) 获取被 ajax 重定向后的接口数据
         api = API["info"]["user_tag"]
-        params = {"mid": self.__uid}
-        if self.credential is None:
-            cookies = Credential().get_cookies()
-        else:
-            cookies = self.credential.get_cookies()
-        # cookies["buvid3"] = str(uuid.uuid1())
-        cookies["Domain"] = ".bilibili.com"
-        sess = get_session()
-        resp = await sess.request(
-            "GET",
-            url=api["url"],
-            params=params,
-            follow_redirects=True,
-            cookies=cookies,
-        )
-        try:
-            r_json = json.loads(resp.text)
-        except JSONDecodeError:
-            r_json = {"status": False, "data": f"解析接口返回的数据失败:{resp.status_code}"}
-        if not r_json:
-            r_json = {"status": False, "data": "Failed"}
-        return r_json
+        params = {"vmid": self.__uid}#, "pn": pn, "ps": ps}
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_space_notice(self) -> dict:
         """
@@ -234,9 +276,7 @@ class User:
         """
         api = API["info"]["space_notice"]
         params = {"mid": self.__uid}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def set_space_notice(self, content: str = "") -> dict:
         """
@@ -254,9 +294,7 @@ class User:
 
         api = API["operate"]["set_space_notice"]
         data = {"notice": content}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_relation_info(self) -> dict:
         """
@@ -267,9 +305,7 @@ class User:
         """
         api = API["info"]["relation"]
         params = {"vmid": self.__uid}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_up_stat(self) -> dict:
         """
@@ -282,9 +318,7 @@ class User:
 
         api = API["info"]["upstat"]
         params = {"mid": self.__uid}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_top_videos(self) -> dict:
         """
@@ -295,9 +329,7 @@ class User:
         """
         api = API["info"]["user_top_videos"]
         params = {"vmid": self.get_uid()}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_user_medal(self) -> dict:
         """
@@ -310,9 +342,7 @@ class User:
         # self.credential.raise_for_no_bili_jct()
         api = API["info"]["user_medal"]
         params = {"target_id": self.__uid}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_live_info(self) -> dict:
         """
@@ -323,9 +353,7 @@ class User:
         """
         api = API["info"]["live"]
         params = {"mid": self.__uid}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_videos(
         self,
@@ -340,13 +368,17 @@ class User:
 
         Args:
             tid     (int, optional)       : 分区 ID. Defaults to 0（全部）.
+
             pn      (int, optional)       : 页码，从 1 开始. Defaults to 1.
+
             ps      (int, optional)       : 每一页的视频数. Defaults to 30.
+
             keyword (str, optional)       : 搜索关键词. Defaults to "".
+
             order   (VideoOrder, optional): 排序方式. Defaults to VideoOrder.PUBDATE
 
         Returns:
-            dict.
+            dict: 调用接口返回的内容。
         """
         api = API["info"]["video"]
         params = {
@@ -357,9 +389,7 @@ class User:
             "keyword": keyword,
             "order": order.value,
         }
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_audios(
         self, order: AudioOrder = AudioOrder.PUBDATE, pn: int = 1, ps: int = 30
@@ -377,9 +407,7 @@ class User:
         """
         api = API["info"]["audio"]
         params = {"uid": self.__uid, "ps": ps, "pn": pn, "order": order.value}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_album(
         self, biz: AlbumType = AlbumType.ALL, page_num: int = 1, page_size: int = 30
@@ -389,7 +417,9 @@ class User:
 
         Args:
             biz (AlbumType, optional): 排序方式. Defaults to AlbumType.ALL.
+
             page_num      (int, optional)       : 页码数，从 1 开始。 Defaults to 1.
+
             page_size    (int)       : 每一页的相簿条目. Defaults to 30.
 
         Returns:
@@ -402,9 +432,7 @@ class User:
             "page_size": page_size,
             "biz": biz.value,
         }
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_articles(
         self, pn: int = 1, order: ArticleOrder = ArticleOrder.PUBDATE, ps: int = 30
@@ -414,7 +442,9 @@ class User:
 
         Args:
             order (ArticleOrder, optional): 排序方式. Defaults to ArticleOrder.PUBDATE.
+
             pn    (int, optional)         : 页码数，从 1 开始。 Defaults to 1.
+
             ps      (int, optional)       : 每一页的视频数. Defaults to 30.
 
         Returns:
@@ -422,9 +452,7 @@ class User:
         """
         api = API["info"]["article"]
         params = {"mid": self.__uid, "ps": ps, "pn": pn, "sort": order.value}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential, wbi=True).update_params(**params).result
 
     async def get_article_list(
         self, order: ArticleListOrder = ArticleListOrder.LATEST
@@ -440,9 +468,7 @@ class User:
         """
         api = API["info"]["article_lists"]
         params = {"mid": self.__uid, "sort": order.value}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_dynamics(self, offset: int = 0, need_top: bool = False) -> dict:
         """
@@ -450,11 +476,16 @@ class User:
 
         Args:
             offset (str, optional):     该值为第一次调用本方法时，数据中会有个 next_offset 字段，
+
                                         指向下一动态列表第一条动态（类似单向链表）。
+
                                         根据上一次获取结果中的 next_offset 字段值，
+
                                         循环填充该值即可获取到全部动态。
+
                                         0 为从头开始。
                                         Defaults to 0.
+
             need_top (bool, optional):  显示置顶动态. Defaults to False.
 
         Returns:
@@ -466,9 +497,7 @@ class User:
             "offset_dynamic_id": offset,
             "need_top": 1 if need_top else 0,
         }
-        data = await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        data = await Api(**api, credential=self.credential).update_params(**params).result
         # card 字段自动转换成 JSON。
         if "cards" in data:
             for card in data["cards"]:
@@ -477,34 +506,51 @@ class User:
         return data
 
     async def get_subscribed_bangumi(
-        self, pn: int = 1, type_: BangumiType = BangumiType.BANGUMI
+        self,
+        type_: BangumiType = BangumiType.BANGUMI,
+        follow_status: BangumiFollowStatus = BangumiFollowStatus.ALL,
+        pn: int = 1,
+        ps: int = 15,
     ) -> dict:
         """
         获取用户追番/追剧列表。
 
         Args:
             pn    (int, optional)         : 页码数，从 1 开始。 Defaults to 1.
+
+            ps      (int, optional)       : 每一页的番剧数. Defaults to 15.
+
             type_ (BangumiType, optional): 资源类型. Defaults to BangumiType.BANGUMI
 
+            follow_status (BangumiFollowStatus, optional): 追番状态. Defaults to BangumiFollowStatus.ALL
+
         Returns:
             dict: 调用接口返回的内容。
         """
         api = API["info"]["bangumi"]
-        params = {"vmid": self.__uid, "pn": pn, "ps": 15, "type": type_.value}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        params = {
+            "vmid": self.__uid,
+            "pn": pn,
+            "ps": ps,
+            "type": type_.value,
+            "follow_status": follow_status.value,
+        }
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_followings(
-        self, pn: int = 1, ps: int = 100, attention: bool = False
+        self, pn: int = 1, ps: int = 100, attention: bool = False, order: OrderType = OrderType.desc
     ) -> dict:
         """
         获取用户关注列表（不是自己只能访问前 5 页）
 
         Args:
             pn        (int, optional)  : 页码，从 1 开始. Defaults to 1.
+
             ps        (int, optional)  : 每页的数据量. Defaults to 100.
-            attention (bool, optional) : 是否采用“最常访问”排序. Defaults to False.
+
+            attention (bool, optional) : 是否采用“最常访问”排序，否则为“关注顺序”排序. Defaults to False.
+
+            order     (OrderType, optional) : 排序方式. Defaults to OrderType.desc.
 
         Returns:
             dict: 调用接口返回的内容。
@@ -515,10 +561,9 @@ class User:
             "ps": ps,
             "pn": pn,
             "order_type": "attention" if attention else "",
+            "order": order.value
         }
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_all_followings(self) -> dict:
         """
@@ -547,7 +592,9 @@ class User:
 
         Args:
             pn   (int, optional) : 页码，从 1 开始. Defaults to 1.
+
             ps   (int, optional) : 每页的数据量. Defaults to 100.
+
             desc (bool, optional): 倒序排序. Defaults to True.
 
         Returns:
@@ -560,9 +607,7 @@ class User:
             "pn": pn,
             "order": "desc" if desc else "asc",
         }
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_self_same_followers(self, pn: int = 1, ps: int = 50) -> dict:
         """
@@ -570,6 +615,7 @@ class User:
 
         Args:
             pn (int): 页码. Defaults to 1.
+
             ps (int): 单页数据量. Defaults to 50.
 
         Returns:
@@ -578,9 +624,7 @@ class User:
         self.credential.raise_for_no_sessdata()
         api = API["info"]["get_same_followings"]
         params = {"vmid": self.get_uid(), "pn": pn, "ps": ps}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def top_followers(self, since=None) -> dict:
         """
@@ -595,9 +639,7 @@ class User:
         params = {}
         if since:
             params["t"] = int(since)
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_overview_stat(self) -> dict:
         """
@@ -608,9 +650,7 @@ class User:
         """
         api = API["info"]["overview"]
         params = {"mid": self.__uid, "jsonp": "jsonp"}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     # 操作用户
 
@@ -630,9 +670,7 @@ class User:
 
         api = API["operate"]["modify"]
         data = {"fid": self.__uid, "act": relation.value, "re_src": 11}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     # 有关合集与列表
 
@@ -648,23 +686,23 @@ class User:
 
         Args:
             sid(int): 频道的 series_id
+
             pn(int) : 页数，默认为 1
+
             ps(int) : 每一页显示的视频数量
 
         Returns:
             dict: 调用接口返回的内容
         """
         api = API["info"]["channel_video_series"]
-        param = {
+        params = {
             "mid": self.__uid,
             "series_id": sid,
             "pn": pn,
             "ps": ps,
             "sort": "asc" if ChannelOrder.CHANGE else "desc",
         }
-        return await request(
-            "GET", url=api["url"], params=param, credential=self.credential
-        )
+        return await Api(**api, wbi=True, credential=self.credential).update_params(**params).result
 
     async def get_channel_videos_season(
         self,
@@ -678,47 +716,46 @@ class User:
 
         Args:
             sid(int)          : 频道的 season_id
+
             sort(ChannelOrder): 排序方式
+
             pn(int)           : 页数，默认为 1
+
             ps(int)           : 每一页显示的视频数量
 
         Returns:
             dict: 调用接口返回的内容
         """
         api = API["info"]["channel_video_season"]
-        param = {
+        params = {
             "mid": self.__uid,
             "season_id": sid,
             "sort_reverse": sort.value,
             "page_num": pn,
             "page_size": ps,
         }
-        return await request(
-            "GET", url=api["url"], params=param, credential=self.credential
-        )
+        return await Api(**api, wbi=True,credential=self.credential).update_params(**params).result
 
     async def get_channel_list(self) -> dict:
         """
         查看用户所有的频道（包括新版）和部分视频。
+
         适用于获取列表。
+
         未处理数据。不推荐。
 
         Returns:
             dict: 调用接口返回的结果
         """
         api = API["info"]["channel_list"]
-        param = {"mid": self.__uid, "page_num": 1, "page_size": 1}
-        res = await request(
-            "GET", url=api["url"], params=param, credential=self.credential
-        )
+        params = {"mid": self.__uid, "page_num": 1, "page_size": 1}
+        res = await Api(**api, wbi=True, credential=self.credential).update_params(**params).result
         items = res["items_lists"]["page"]["total"]
         time.sleep(0.5)
         if items == 0:
             items = 1
-        param["page_size"] = items
-        return await request(
-            "GET", url=api["url"], params=param, credential=self.credential
-        )
+        params["page_size"] = items
+        return await Api(**api, wbi=True,credential=self.credential).update_params(**params).result
 
     async def get_channels(self) -> List["ChannelSeries"]:
         """
@@ -764,7 +801,7 @@ class User:
         """
         api = API["info"]["pugv"]
         params = {"mid": self.__uid}
-        return await request("GET", api["url"], params=params)
+        return await Api(**api, wbi=True, credential=self.credential).update_params(**params).result
 
     async def get_reservation(self) -> dict:
         """
@@ -775,9 +812,18 @@ class User:
         """
         api = API["info"]["reservation"]
         params = {"vmid": self.get_uid()}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
+
+    async def get_elec_user_monthly(self) -> dict:
+        """
+        获取空间充电公示信息
+
+        Returns:
+            dict: 调用接口返回的结果
+        """
+        api = API["info"]["elec_user_monthly"]
+        params = {"up_mid": self.get_uid()}
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
 
 async def get_self_info(credential: Credential) -> dict:
@@ -790,7 +836,7 @@ async def get_self_info(credential: Credential) -> dict:
     api = API["info"]["my_info"]
     credential.raise_for_no_sessdata()
 
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def edit_self_info(
@@ -801,9 +847,13 @@ async def edit_self_info(
 
     Args:
         birthday (str)      : 生日 YYYY-MM-DD
+
         sex (str)           : 性别 男|女|保密
+
         uname (str)         : 用户名
+
         usersign (str)      : 个性签名
+
         credential (Credential): Credential
     """
 
@@ -813,7 +863,7 @@ async def edit_self_info(
     api = API["info"]["edit_my_info"]
     data = {"birthday": birthday, "sex": sex, "uname": uname, "usersign": usersign}
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def create_subscribe_group(name: str, credential: Credential) -> dict:
@@ -822,6 +872,7 @@ async def create_subscribe_group(name: str, credential: Credential) -> dict:
 
     Args:
         name       (str)       : 分组名
+
         credential (Credential): Credential
 
     Returns:
@@ -833,7 +884,7 @@ async def create_subscribe_group(name: str, credential: Credential) -> dict:
     api = API["operate"]["create_subscribe_group"]
     data = {"tag": name}
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def delete_subscribe_group(group_id: int, credential: Credential) -> dict:
@@ -842,6 +893,7 @@ async def delete_subscribe_group(group_id: int, credential: Credential) -> dict:
 
     Args:
         group_id   (int)       : 分组 ID
+
         credential (Credential): Credential
 
     Returns:
@@ -853,7 +905,7 @@ async def delete_subscribe_group(group_id: int, credential: Credential) -> dict:
     api = API["operate"]["del_subscribe_group"]
     data = {"tagid": group_id}
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def rename_subscribe_group(
@@ -864,7 +916,9 @@ async def rename_subscribe_group(
 
     Args:
         group_id   (int)       : 分组 ID
+
         new_name   (str)       : 新的分组名
+
         credential (Credential): Credential
 
     Returns:
@@ -876,7 +930,7 @@ async def rename_subscribe_group(
     api = API["operate"]["rename_subscribe_group"]
     data = {"tagid": group_id, "name": new_name}
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def set_subscribe_group(
@@ -887,7 +941,9 @@ async def set_subscribe_group(
 
     Args:
         uids       (List[int]) : 要设置的用户 UID 列表，必须已关注。
+
         group_ids  (List[int]) : 要复制到的分组列表
+
         credential (Credential): Credential
 
     Returns:
@@ -899,7 +955,7 @@ async def set_subscribe_group(
     api = API["operate"]["set_user_subscribe_group"]
     data = {"fids": join(",", uids), "tagids": join(",", group_ids)}
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def get_self_history(
@@ -908,11 +964,13 @@ async def get_self_history(
     credential: Union[Credential, None] = None,
 ) -> dict:
     """
-    获取用户浏览历史记录
+    获取用户浏览历史记录（旧版）
 
     Args:
         page_num (int): 页码数
+
         per_page_item (int): 每页多少条历史记录
+
         credential (Credential): Credential
 
     Returns:
@@ -926,10 +984,51 @@ async def get_self_history(
     api = API["info"]["history"]
     params = {"pn": page_num, "ps": per_page_item}
 
-    return await request("GET", url=api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
-async def get_self_coins(credential: Credential):
+async def get_self_history_new(
+    credential: Credential,
+    _type: HistoryType = HistoryType.ALL,
+    ps: int = 20,
+    view_at: int = None,
+    max: int = None,
+    business: HistoryBusinessType = None,
+) -> dict:
+    """
+    获取用户浏览历史记录（新版），与旧版不同有分类参数，但相对缺少视频信息
+
+    max、business、view_at 参数用于历史记录列表的 IFS (无限滚动)，其用法类似链表的 next 指针
+
+    将返回值某历史记录的 oid、business、view_at 作为上述参数传入，即可获取此 oid 之前的历史记录
+
+    Args:
+        credential (Credential) : Credential
+
+        _type      (HistroyType): 历史记录分类, 默认为 HistroyType.ALL
+
+        ps         (int)        : 每页多少条历史记录, 默认为 20
+
+        view_at    (int)        : 时间戳，获取此时间戳之前的历史记录
+
+        max        (int)        : 历史记录截止目标 oid
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    credential.raise_for_no_sessdata()
+    api = API["info"]["history_new"]
+    params = {
+        "type": _type.value,
+        "ps": ps,
+        "view_at": view_at,
+        "max": max,
+        "business": business if business is None else business.value,
+    }
+    return await Api(**api, credential=credential).update_params(**params).result
+
+
+async def get_self_coins(credential: Credential) -> int:
     """
     获取自己的硬币数量。
 
@@ -941,7 +1040,7 @@ async def get_self_coins(credential: Credential):
     credential.raise_for_no_sessdata()
     credential.raise_for_no_dedeuserid()
     api = API["info"]["get_coins"]
-    return (await request("GET", url=api["url"], credential=credential))["money"]
+    return (await Api(**api, credential=credential).result)["money"]
 
 
 async def get_self_special_followings(
@@ -952,13 +1051,15 @@ async def get_self_special_followings(
 
     Args:
         credential (Credential)   : 凭据类
+
         pn         (int, optional): 页码. Defaults to 1.
+
         ps         (int, optional): 每页数据大小. Defaults to 50.
     """
     credential.raise_for_no_sessdata()
     api = API["info"]["get_special_followings"]
     params = {"pn": pn, "ps": ps}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_self_whisper_followings(
@@ -969,13 +1070,15 @@ async def get_self_whisper_followings(
 
     Args:
         credential (Credential)   : 凭据类
+
         pn         (int, optional): 页码. Defaults to 1.
+
         ps         (int, optional): 每页数据大小. Defaults to 50.
     """
     credential.raise_for_no_sessdata()
     api = API["info"]["get_whisper_followings"]
     params = {"pn": pn, "ps": ps}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_self_friends(credential: Credential) -> dict:
@@ -987,7 +1090,7 @@ async def get_self_friends(credential: Credential) -> dict:
     """
     credential.raise_for_no_sessdata()
     api = API["info"]["get_friends"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_self_black_list(
@@ -998,13 +1101,15 @@ async def get_self_black_list(
 
     Args:
         credential (Credential)   : 凭据类
+
         pn         (int, optional): 页码. Defaults to 1.
+
         ps         (int, optional): 每页数据大小. Defaults to 50.
     """
     credential.raise_for_no_sessdata()
     api = API["info"]["get_black_list"]
     params = {"pn": pn, "ps": ps}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_toview_list(credential: Credential):
@@ -1019,7 +1124,7 @@ async def get_toview_list(credential: Credential):
     """
     api = get_api("toview")["info"]["list"]
     credential.raise_for_no_sessdata()
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def clear_toview_list(credential: Credential):
@@ -1035,7 +1140,7 @@ async def clear_toview_list(credential: Credential):
     api = get_api("toview")["operate"]["clear"]
     credential.raise_for_no_sessdata()
     credential.raise_for_no_bili_jct()
-    return await request("POST", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def delete_viewed_videos_from_toview(credential: Credential):
@@ -1052,10 +1157,10 @@ async def delete_viewed_videos_from_toview(credential: Credential):
     credential.raise_for_no_sessdata()
     credential.raise_for_no_bili_jct()
     datas = {"viewed": "true"}
-    return await request("POST", api["url"], credential=credential, data=datas)
+    return await Api(**api, credential=credential).update_data(**datas).result
 
 
-async def check_nickname(nick_name: str):
+async def check_nickname(nick_name: str) -> Tuple[bool, str]:
     """
     检验昵称是否可用
 
@@ -1068,7 +1173,7 @@ async def check_nickname(nick_name: str):
     api = get_api("common")["nickname"]["check_nickname"]
     params = {"nickName": nick_name}
     try:
-        resp = await request("GET", api["url"], params=params)
+        resp = await Api(**api).update_params(**params).result
     except ResponseCodeException as e:
         return False, str(e)
     else:
@@ -1081,6 +1186,7 @@ async def get_self_events(ts: int = 0, credential: Union[Credential, None] = Non
 
     Args:
         ts(int, optional)                      : 时间戳. Defaults to 0.
+
         credential(Credential | None, optional): 凭据. Defaults to None.
 
     Returns:
@@ -1089,7 +1195,7 @@ async def get_self_events(ts: int = 0, credential: Union[Credential, None] = Non
     credential = credential if credential else Credential()
     api = API["info"]["events"]
     params = {"ts": ts}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_self_notes_info(
@@ -1100,7 +1206,9 @@ async def get_self_notes_info(
 
     Args:
         page_num: 页码
+
         page_size: 每页项数
+
         credential(Credential): 凭据类
 
     Returns:
@@ -1114,7 +1222,7 @@ async def get_self_notes_info(
 
     api = API["info"]["all_notes"]
     params = {"pn": page_num, "ps": page_size}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_self_public_notes_info(
@@ -1125,7 +1233,9 @@ async def get_self_public_notes_info(
 
     Args:
         page_num: 页码
+
         page_size: 每页项数
+
         credential(Credential): 凭据类
 
     Returns:
@@ -1139,7 +1249,8 @@ async def get_self_public_notes_info(
 
     api = API["info"]["public_notes"]
     params = {"pn": page_num, "ps": page_size}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
+
 
 async def get_self_jury_info(credential: Credential) -> dict:
     """
@@ -1147,4 +1258,4 @@ async def get_self_jury_info(credential: Credential) -> dict:
     """
     credential.raise_for_no_sessdata()
     api = API["info"]["jury"]
-    return await request("GET", api["url"], credential=credential)
\ No newline at end of file
+    return await Api(**api, credential=credential).result
