@@ -4,13 +4,15 @@ bilibili_api.video_tag
 视频标签相关，部分的标签的 id 与同名的频道的 id 一模一样。
 """
 
-from .utils.Credential import Credential
-from .utils.network_httpx import request
-from .utils.utils import get_api
-from .errors import *
-import httpx
 from typing import Optional
 
+import httpx
+
+from .errors import *
+from .utils.utils import get_api
+from .utils.credential import Credential
+from .utils.network_httpx import Api
+
 API = get_api("video_tag")
 API_video = get_api("video")
 
@@ -29,7 +31,9 @@ class Tag:
         """
         Args:
             tag_name   (str | None): 标签名. Defaults to None.
+
             tag_id     (int | None): 标签 id. Defaults to None.
+
             credential (Credential): 凭据类. Defaults to None.
 
         注意：tag_name 和 tag_id 任选一个传入即可。tag_id 优先使用。
@@ -58,7 +62,7 @@ class Tag:
         """
         api = API["info"]["tag_info"]
         params = {"tag_id": self.get_tag_id()}
-        return await request("GET", api["url"], params=params)
+        return await Api(**api).update_params(**params).result
 
     async def get_similar_tags(self) -> dict:
         """
@@ -69,7 +73,7 @@ class Tag:
         """
         api = API["info"]["get_similar"]
         params = {"tag_id": self.get_tag_id()}
-        return await request("GET", api["url"], params=params)
+        return await Api(**api).update_params(**params).result
 
     async def get_cards(self) -> dict:
         """
@@ -80,16 +84,18 @@ class Tag:
         """
         api = API["info"]["get_list"]
         params = {"topic_id": self.get_tag_id()}
-        return await request("GET", api["url"], params=params)
-    async def get_history_cards(self,offset_dynamic_id:int)-> dict:
+        return await Api(**api).update_params(**params).result
+
+    async def get_history_cards(self, offset_dynamic_id: int) -> dict:
         """
         获取标签下，指定dynamic_id的视频的后一个视频/动态作为起始的视频/动态
+
         Returns:
             dict: 调用 API 返回的结果
         """
         api = API["info"]["get_history_list"]
         params = {"topic_id": self.get_tag_id(), "offset_dynamic_id": offset_dynamic_id}
-        return await request("GET", api["url"], params=params)
+        return await Api(**api).update_params(**params).result
 
     async def subscribe_tag(self) -> dict:
         """
@@ -104,9 +110,7 @@ class Tag:
         api = API_video["operate"]["subscribe_tag"]
 
         data = {"tag_id": self.__tag_id}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(data).result
 
     async def unsubscribe_tag(self) -> dict:
         """
@@ -121,6 +125,4 @@ class Tag:
         api = API_video["operate"]["unsubscribe_tag"]
 
         data = {"tag_id": self.__tag_id}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(data).result
