@@ -3,32 +3,29 @@ bilibili_api.video_uploader
 
 视频上传
 """
-import asyncio
-from asyncio.exceptions import CancelledError
-from asyncio.tasks import Task, create_task
 import os
+import json
 import time
+import base64
 import random
+import asyncio
+from enum import Enum
+from typing import List, Union
+from copy import copy, deepcopy
+from asyncio.tasks import Task, create_task
+from asyncio.exceptions import CancelledError
 
 from .video import Video
-from .utils.aid_bvid_transformer import bvid2aid
-from .utils.Credential import Credential
-from .utils.Picture import Picture
-from copy import copy, deepcopy
-from .exceptions.ResponseCodeException import ResponseCodeException
-import json
-import base64
-from enum import Enum
-
-from .exceptions.ApiException import ApiException
-from .exceptions.NetworkException import NetworkException
-from typing import List, Union
-
-from .utils.AsyncEvent import AsyncEvent
-from .utils.network_httpx import get_session, request
 from .utils.utils import get_api
-
 from .dynamic import upload_image
+from .utils.picture import Picture
+from .utils.AsyncEvent import AsyncEvent
+from .utils.credential import Credential
+from .utils.aid_bvid_transformer import bvid2aid
+from .exceptions.ApiException import ApiException
+from .utils.network_httpx import Api, get_session
+from .exceptions.NetworkException import NetworkException
+from .exceptions.ResponseCodeException import ResponseCodeException
 
 # import ffmpeg
 
@@ -41,7 +38,7 @@ async def _upload_cover(cover: Picture, credential: Credential):
     data = {
         "cover": f'data:image/png;base64,{base64.b64encode(cover.content).decode("utf-8")}'
     }
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 class VideoUploaderPage:
@@ -147,8 +144,11 @@ class VideoUploader(AsyncEvent):
 
     Attributes:
         pages        (List[VideoUploaderPage]): 分 P 列表
+
         meta         (dict)                   : 视频信息
+
         credential   (Credential)             : 凭据
+
         cover_path   (str)                    : 封面路径
     """
 
@@ -163,8 +163,11 @@ class VideoUploader(AsyncEvent):
         """
         Args:
             pages        (List[VideoUploaderPage]): 分 P 列表
+
             meta         (dict)                   : 视频信息
+
             credential   (Credential)             : 凭据
+
             cover        (str | Picture)          : 封面路径 / Picture 对象
 
         meta 参数示例：
@@ -467,8 +470,7 @@ class VideoUploader(AsyncEvent):
                 else Picture().from_file(self.cover_path)
             )
             resp = await _upload_cover(pic, self.credential)
-            self.dispatch(VideoUploaderEvents.AFTER_COVER.value,
-                          {"url": resp["url"]})
+            self.dispatch(VideoUploaderEvents.AFTER_COVER.value, {"url": resp["url"]})
             return resp["url"]
         except Exception as e:
             self.dispatch(VideoUploaderEvents.COVER_FAILED.value, {"err": e})
@@ -652,8 +654,11 @@ class VideoUploader(AsyncEvent):
 
         Args:
             page (VideoUploaderPage): 分 P 对象
+
             chunks (int): 分块数量
+
             preupload (dict): preupload 数据
+
             upload_id (str): upload_id
 
         Returns:
@@ -719,6 +724,7 @@ class VideoUploader(AsyncEvent):
 
         Args:
             videos (list): 视频列表
+
             cover_url (str, optional): 封面 URL.
 
         Returns:
@@ -732,16 +738,13 @@ class VideoUploader(AsyncEvent):
         api = _API["submit"]
 
         try:
-            resp = await request(
-                "POST",
-                api["url"],
-                params={"csrf": self.credential.bili_jct},
-                data=json.dumps(meta),
-                headers={"content-type": "application/json"},
-                credential=self.credential,
-                no_csrf=True,
-            )
-
+            params = {"csrf": self.credential.bili_jct}
+            data = json.dumps(meta)
+            headers = {"content-type": "application/json"}
+            resp = await Api(**api, credential=self.credential, no_csrf=True
+                             ).update_params(**params
+                                             ).update_data(**data
+                                                           ).update_headers(**headers).result
             self.dispatch(VideoUploaderEvents.AFTER_SUBMIT.value, resp)
             return resp
 
@@ -765,6 +768,7 @@ async def get_missions(tid: int = 0, credential: Union[Credential, None] = None)
 
     Args:
         tid        (int, optional)       : 分区 ID. Defaults to 0.
+
         credential (Credential, optional): 凭据. Defaults to None.
 
     Returns:
@@ -774,7 +778,7 @@ async def get_missions(tid: int = 0, credential: Union[Credential, None] = None)
 
     params = {"tid": tid}
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 class VideoEditorEvents(Enum):
@@ -818,8 +822,11 @@ class VideoEditor(AsyncEvent):
 
     Attributes:
         bvid (str)             : 稿件 BVID
+
         meta (dict)            : 视频信息
+
         cover_path (str)       : 封面路径. Defaults to None(不更换封面).
+
         credential (Credential): 凭据类. Defaults to None.
     """
 
@@ -833,8 +840,11 @@ class VideoEditor(AsyncEvent):
         """
         Args:
             bvid (str)                    : 稿件 BVID
+
             meta (dict)                   : 视频信息
+
             cover (str | Picture)         : 封面地址. Defaults to None(不更改封面).
+
             credential (Credential | None): 凭据类. Defaults to None.
 
         meta 参数示例: (保留 video, cover, tid, aid 字段)
@@ -878,9 +888,7 @@ class VideoEditor(AsyncEvent):
         try:
             api = _API["upload_args"]
             params = {"bvid": self.bvid}
-            self.__old_configs = await request(
-                "GET", api["url"], params=params, credential=self.credential
-            )
+            self.__old_configs = await Api(**api, credential=self.credential).update_params(**params).result
         except Exception as e:
             self.dispatch(VideoEditorEvents.PRELOAD_FAILED.value, {"err", e})
             raise e
@@ -906,7 +914,8 @@ class VideoEditor(AsyncEvent):
             )
             resp = await _upload_cover(pic, self.credential)
             self.dispatch(VideoEditorEvents.AFTER_COVER.value, {"url": resp["url"]})
-            self.meta["cover"] = resp["image_url"]  # not sure if this key changed to "url" as well
+            # not sure if this key changed to "url" as well
+            self.meta["cover"] = resp["image_url"]
         except Exception as e:
             self.dispatch(VideoEditorEvents.COVER_FAILED.value, {"err": e})
             raise e
@@ -917,19 +926,17 @@ class VideoEditor(AsyncEvent):
         datas["csrf"] = self.credential.bili_jct
         self.dispatch(VideoEditorEvents.PRE_SUBMIT.value)
         try:
-            resp = await request(
-                "POST",
-                api["url"],
-                params={"csrf": self.credential.bili_jct, "t": int(time.time())},
-                data=json.dumps(datas),
-                headers={
-                    "content-type": "application/json;charset=UTF-8",
-                    "referer": "https://member.bilibili.com",
-                    "user-agent": "Mozilla/5.0",
-                },
-                credential=self.credential,
-                no_csrf=True,
-            )
+            params={"csrf": self.credential.bili_jct, "t": int(time.time())},
+            data=json.dumps(datas),
+            headers={
+                "content-type": "application/json;charset=UTF-8",
+                "referer": "https://member.bilibili.com",
+                "user-agent": "Mozilla/5.0",
+            }
+            resp = await Api(**api, credential=self.credential, no_csrf=True
+                             ).update_params(**params
+                                             ).update_data(**data
+                                                           ).update_headers(**headers).result
             self.dispatch(VideoEditorEvents.AFTER_SUBMIT.value, resp)
         except Exception as e:
             self.dispatch(VideoEditorEvents.SUBMIT_FAILED.value, {"err", e})
