@@ -4,16 +4,16 @@ bilibili_api.video_zone
 分区相关操作，与频道不互通。
 """
 
-import json
 import os
 import copy
 import enum
-from typing import Tuple, Union, List, Dict
+import json
+from typing import Dict, List, Tuple, Union
 
-from .exceptions import ArgsException
 from .utils.utils import get_api
-from .utils.network_httpx import request
-from .utils.Credential import Credential
+from .exceptions import ArgsException
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 
 API = get_api("video_zone")
 
@@ -84,7 +84,9 @@ async def get_zone_top10(
 
     Args:
         tid        (int)                        : 频道的 tid。
+
         day        (int, optional)              : 3 天排行还是 7 天排行。 Defaults to 7.
+
         credential (Credential | None, optional): Credential 类。Defaults to None.
 
     Returns:
@@ -95,9 +97,9 @@ async def get_zone_top10(
     if day not in (3, 7):
         raise ArgsException("参数 day 只能是 3，7。")
 
-    url = API["ranking"]["get_top10"]["url"]
+    api = API["ranking"]["get_top10"]
     params = {"rid": tid, "day": day}
-    return await request("GET", url, params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 def get_zone_list() -> List[Dict]:
@@ -147,12 +149,13 @@ async def get_zone_videos_count_today(
 
     Args:
         credential (Credential | None): 凭据类
+
     Returns:
         dict: 调用 API 返回的结果
     """
     credential = credential if credential else Credential()
     api = API["count"]
-    return (await request("GET", api["url"], credential=credential))["region_count"]
+    return (await Api(**api, credential=credential).result)["region_count"]
 
 
 async def get_zone_new_videos(tid: int, page_num: int = 1, page_size: int = 10) -> dict:
@@ -161,7 +164,9 @@ async def get_zone_new_videos(tid: int, page_num: int = 1, page_size: int = 10)
 
     Args:
         tid        (int)              : 分区 id
+
         page_num   (int)              : 第几页. Defaults to 1.
+
         page_size  (int)              : 每页的数据大小. Defaults to 10.
 
     Returns:
@@ -169,7 +174,7 @@ async def get_zone_new_videos(tid: int, page_num: int = 1, page_size: int = 10)
     """
     api = API["new"]
     params = {"rid": tid, "pn": page_num, "ps": page_size}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def get_zone_hot_tags(tid: int) -> List[dict]:
@@ -185,7 +190,7 @@ async def get_zone_hot_tags(tid: int) -> List[dict]:
 
     api = API["get_hot_tags"]
     params = {"rid": tid}
-    return (await request("GET", api["url"], params=params))[0]
+    return (await Api(**api).update_params(**params).result)[0]
 
 
 class VideoZoneTypes(enum.Enum):
